# Cryptography

This is the repository for ciphers built in Python that Gemcoin is adopting for message relay. Our current supported ciphers are listed below by category.

## Ciphers

| Block Ciphers                 |
| ----------------------------- |

| Implementation  | Usage |
| ------------- | ------------- |
| AES CBC      | Not currently used     |
| AES CTR      | Currently used with external library     |


## Auditing

If you can find bugs in our code, we will offer you a job at Gemcoin. All bug bounties are paid in Gems.

---

Created by Vlad Usatii @ gemcoin
